export interface URLDataSyncInProps<Data> {
    readonly data: Data;
    readonly dataError: Error | null | undefined;
    readonly isLoadingData: boolean;
    readonly urlQuery: URLQueryMap;
    saveData(): void;
    updateData(data: Partial<Data>): void;
    /** Update URL query parameters without reloading and trigger a re-sync. */
    updateURLQuery(...queries: readonly URLQueryMap[]): void;
}
export interface URLDataSyncOutProps<Data> {
    /** This is used for the data synchronizer. */
    readonly additionalDataQuery?: Repository.URLDataSync.AdditionalQuery;
    readonly initialData: Data;
    readonly urlDataSync: Repository.URLDataSync;
    readonly onDataChange?: (data: Data) => void;
}
/**
 * Automatically sync with current URL by requesting data from server using
 * said URL. This is assuming there is data provided by the server at current
 * URL, e.g. user navigates to /users/1, this will send a GET request to
 * /users/1, which should have a defined backend route that contains the
 * relevant data.
 *
 * This HOC is usually used for components rendered by a Route. Please make sure
 * when implementing the backend to handle these requests that it never returns
 * null/undefined (as per REST design standards).
 */
export declare function urlDataSync<Data, OutProps = {}>(): FunctionalEnhancer<URLDataSyncInProps<Data> & OutProps, URLDataSyncOutProps<Data> & OutProps>;
export interface CursorPaginatedData<T> {
    readonly results: readonly T[];
    readonly count: number;
    readonly limit: number;
    readonly next?: string;
    readonly previous?: string;
}
export interface CursorPaginationInProps<T> extends Pick<URLDataSyncOutProps<CursorPaginatedData<T>>, "additionalDataQuery" | "initialData" | "onDataChange"> {
    readonly page: number;
}
/**
 * This works with the auto-sync HOC to provide paginated data. It is assumed
 * that the server will return the data in the above format - the cursor markers
 * will be stored internally and fed the next time we perform a GET request.
 */
export declare function cursorPagination<T, OutProps = {}>(): FunctionalEnhancer<CursorPaginationInProps<T> & OutProps, OutProps>;
export interface CursorPaginatedDataInProps<T> extends Pick<URLDataSyncInProps<readonly (T | undefined)[]>, "data">, Pick<CursorPaginationInProps<any>, "page"> {
}
export interface CursorPaginatedDataOutProps<T> extends Pick<URLDataSyncInProps<CursorPaginatedData<T>>, "data">, Pick<CursorPaginationInProps<any>, "page"> {
}
/**
 * This works with the cursor pagination HOC and auto URL data sync to provide
 * a sparsely-populated data array based on the current page. For example, a
 * page of 5 items and total item count of 10 looks like so (x is a valid item,
 * o is undefined):
 * - Page 1: [x, x, x, x, x, o, o, o, o, o].
 * - Page 2: [o, o, o, o, o, x, x, x, x, x].
 */
export declare function cursorPaginatedData<T, OutProps = {}>(): FunctionalEnhancer<CursorPaginatedDataInProps<T> & OutProps, CursorPaginatedDataOutProps<T> & OutProps>;
export interface URLPaginatedDataSyncInProps<T> extends URLDataSyncInProps<readonly (T | undefined)[]>, Pick<CursorPaginatedDataInProps<any>, "page"> {
}
export interface URLPaginatedDataSyncOutProps<T> extends Pick<URLDataSyncOutProps<CursorPaginatedData<T>>, "urlDataSync"> {
}
/**
 * This HOC automatically manages pagination data sync, and is best used to
 * display table data. For other kinds of data use the data sync HOC.
 */
export declare function urlPaginatedDataSync<T>(): FunctionalEnhancer<URLPaginatedDataSyncInProps<T>, URLPaginatedDataSyncOutProps<T>>;
//# sourceMappingURL=dataHOC.d.ts.map